@@ -3,7 +3,7 @@
 /**
   * SquirrelMail CAPTCHA Plugin freeCap Backend
   * Copyright (c) 2005-2007 Howard Yeend
-  * Copyright (c) 2007-2008 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2007-2009 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -105,8 +105,9 @@ function freecap_show_input_widgets()
 /**
   * Validate that correct captcha was sent
   *
-  * @return boolean TRUE if the correct captcha response was sent,
-  *                 otherwise FALSE
+  * @return mixed TRUE if the correct captcha response was sent,
+  *               FALSE if the user input was incorrect, or NULL
+  *               when no user input was given.
   *
   */
 function freecap_validate_captcha()
@@ -115,7 +116,6 @@ function freecap_validate_captcha()
    // just bail if insufficient input is received
    //
    if (!sqGetGlobalVar('captcha_response', $captcha_response, SQ_FORM)
-    || empty($captcha_response)
     || !sqGetGlobalVar('hash_func', $hash_function, SQ_SESSION)
     || empty($hash_function)
     || !sqGetGlobalVar('freecap_word_hash', $word_hash, SQ_SESSION)
@@ -128,6 +128,12 @@ function freecap_validate_captcha()
    sqsession_unregister('hash_func');
 
 
+   // test for no user input
+   //
+   if ($captcha_response === '')
+      return NULL;
+
+
    return $hash_function($captcha_response) == $word_hash;
 
 }
