@@ -6,7 +6,7 @@
   * Copyright (c) 2006-2007 Horst Nogajski <horst@nogajski.de>
   * Copyright (c) 2006-2007 Ben Franske <ben@franske.com>
   * Copyright (c) 2006-2007 Ran Geva <ran@rangeva.com>
-  * Copyright (c) 2007-2008 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2007-2009 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -52,7 +52,7 @@ function hec_show_input_widgets()
    if (!@is_dir($work_dir)) mkdir($work_dir);
 
 
-   $captcha =& new b2evo_captcha($CAPTCHA_CONFIG);
+   $captcha = new b2evo_captcha($CAPTCHA_CONFIG);
 
 
 
@@ -117,8 +117,9 @@ function hec_show_input_widgets()
 /**
   * Validate that correct captcha was sent
   *
-  * @return boolean TRUE if the correct captcha response was sent,
-  *                 otherwise FALSE
+  * @return mixed TRUE if the correct captcha response was sent,
+  *               FALSE if the user input was incorrect, or NULL
+  *               when no user input was given.
   *
   */
 function hec_validate_captcha()
@@ -127,7 +128,6 @@ function hec_validate_captcha()
    // just bail if insufficient input is received
    //
    if (!sqGetGlobalVar('captcha_response', $captcha_response, SQ_FORM)
-    || empty($captcha_response)
     || !sqGetGlobalVar('captcha_hash', $captcha_hash, SQ_SESSION)
     || empty($captcha_hash))
       return FALSE;
@@ -135,12 +135,18 @@ function hec_validate_captcha()
 
    global $CAPTCHA_CONFIG;
    require_once(SM_PATH . 'plugins/captcha/backends/hec/b2evo_captcha.class.php');
-   $captcha =& new b2evo_captcha($CAPTCHA_CONFIG);
+   $captcha = new b2evo_captcha($CAPTCHA_CONFIG);
 
 
    sqsession_unregister('captcha_hash');
 
 
+   // test for no user input
+   //
+   if ($captcha_response === '')
+      return NULL;
+
+
    return $captcha->validate_submit($captcha_hash, $captcha_response);
 
 }
