@@ -3,7 +3,7 @@
 /**
   * SquirrelMail CAPTCHA Plugin PHP Captcha Backend
   * Copyright (c) 2007 Kerem Erkan <kerem@keremerkan.net>
-  * Copyright (c) 2007-2008 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2007-2009 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -105,8 +105,9 @@ function phpcaptcha_show_input_widgets()
 /**
   * Validate that correct captcha was sent
   *
-  * @return boolean TRUE if the correct captcha response was sent,
-  *                 otherwise FALSE
+  * @return mixed TRUE if the correct captcha response was sent,
+  *               FALSE if the user input was incorrect, or NULL
+  *               when no user input was given.
   *
   */
 function phpcaptcha_validate_captcha()
@@ -115,7 +116,6 @@ function phpcaptcha_validate_captcha()
    // just bail if insufficient input is received
    //
    if (!sqGetGlobalVar('captcha', $post_captcha, SQ_FORM)
-    || empty($post_captcha)
     || !sqGetGlobalVar('captcha', $session_captcha, SQ_SESSION)
     || empty($session_captcha))
       return FALSE;
@@ -128,6 +128,12 @@ function phpcaptcha_validate_captcha()
    sqsession_unregister('captcha');
 
 
+   // test for no user input
+   //
+   if ($post_captcha === '')
+      return NULL;
+
+
    return ($captcha_result === 0);
 
 }
