@@ -3,7 +3,7 @@
 /**
   * SquirrelMail CAPTCHA Plugin HTML_QuickForm_CAPTCHA Backend
   * Copyright (c) 2006-2007 Philippe Jausions <Philippe.Jausions@11abacus.com>
-  * Copyright (c) 2007-2008 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2007-2009 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -15,6 +15,7 @@
    if (file_exists('../../../../functions/global.php'))
    {
       define('SM_PATH', '../../../../');
+      include_once(SM_PATH . 'include/constants.php');
       include_once(SM_PATH . 'functions/global.php');
    }
    else exit;
@@ -27,7 +28,7 @@
 
 
    if (!@include_once(SM_PATH . 'plugins/captcha/backends/quickform/quickform_config.php'))
-      include_once(SM_PATH . 'plugins/captcha/backends/quickform/quickform_config.sample.php');
+      include_once(SM_PATH . 'plugins/captcha/backends/quickform/quickform_config_default.php');
 
 
    require_once('HTML/QuickForm.php');
@@ -118,7 +119,7 @@ if ((isset($sSessionAutostartName) || $sSessionAutostartName == '') &&
     $sCookiePath = ini_get('session.cookie_path');
     $sCookieDomain = ini_get('session.cookie_domain');
     // reset the cookie
-    setcookie($sSessionAutostartName,'',time() - 604800,$sCookiePath,$sCookieDomain);
+    sqsetcookie($sSessionAutostartName,'',time() - 604800,$sCookiePath,$sCookieDomain);
     @session_destroy();
     session_write_close();
 }
