@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail CAPTCHA Plugin reCAPTCHA Backend
-  * Copyright (c) 2007-2008 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2007-2009 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -43,30 +43,15 @@ function recaptcha_check_configuration()
 function recaptcha_show_input_widgets()
 {
 
-   global $recaptcha_secure_login_port, $recaptcha_theme, 
+   global $is_secure_connection, $recaptcha_theme, 
           $recaptcha_public_key, $recaptcha_tabindex;
 
 
-   // figure out if we are being accessed under HTTPS -
-   // first get user's access port
+   // determine if this is a secure connection... I suppose
+   // these URIs might be better placed in a config file,
+   // but supposedly they are static
    //
-   if (!sqGetGlobalVar('SERVER_PORT', $server_port, SQ_SERVER))
-      $server_port = 0;
-
-
-   // figure out what port we should be comparing
-   //
-   if (isset($recaptcha_secure_login_port))
-      $target_https_port = $recaptcha_secure_login_port;
-   else
-      $target_https_port = '443';
-
-
-   // now make the comparison... I suppose these URIs might
-   // be better placed in a config file, but supposedly they
-   // are static
-   //
-   if ($server_port == $target_https_port)
+   if ($is_secure_connection)
       $recaptcha_uri = 'https://api-secure.recaptcha.net';
    else
       $recaptcha_uri = 'http://api.recaptcha.net';
@@ -217,8 +202,9 @@ function recaptcha_show_input_widgets()
 /**
   * Validate that correct captcha was sent
   *
-  * @return boolean TRUE if the correct captcha response was sent,
-  *                 otherwise FALSE
+  * @return mixed TRUE if the correct captcha response was sent,
+  *               FALSE if the user input was incorrect, or NULL
+  *               when no user input was given.
   *
   */
 function recaptcha_validate_captcha()
@@ -232,6 +218,12 @@ function recaptcha_validate_captcha()
       return FALSE;
    
 
+   // test for no user input
+   //
+   if ($recaptcha_challenge_field === '' && $recaptcha_response_field === '')
+      return NULL;
+
+
    global $recaptcha_private_key;
    $recapcha_verify_host = 'api-verify.recaptcha.net';
 
