@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail CAPTCHA Plugin Text_CAPTCHA Backend
-  * Copyright (c) 2007-2008 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2007-2009 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -15,6 +15,7 @@
 if (file_exists('../../../../functions/global.php'))
 {
    define('SM_PATH', '../../../../');
+   include_once(SM_PATH . 'include/constants.php');
    include_once(SM_PATH . 'functions/global.php');
 }
 else
@@ -23,7 +24,7 @@ else
 
 
 if (!@include_once(SM_PATH . 'plugins/captcha/backends/textcaptcha/textcaptcha_config.php'))
-   include_once(SM_PATH . 'plugins/captcha/backends/textcaptcha/textcaptcha_config.sample.php');
+   include_once(SM_PATH . 'plugins/captcha/backends/textcaptcha/textcaptcha_config_default.php');
 
 
 
@@ -101,7 +102,7 @@ if ((isset($sSessionAutostartName) || $sSessionAutostartName == '') &&
     $sCookiePath = ini_get('session.cookie_path');
     $sCookieDomain = ini_get('session.cookie_domain');
     // reset the cookie
-    setcookie($sSessionAutostartName,'',time() - 604800,$sCookiePath,$sCookieDomain);
+    sqsetcookie($sSessionAutostartName,'',time() - 604800,$sCookiePath,$sCookieDomain);
     @session_destroy();
     session_write_close();
 }
