@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail CAPTCHA Plugin Text_CAPTCHA Backend
-  * Copyright (c) 2007-2008 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2007-2009 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -104,8 +104,9 @@ function textcaptcha_show_input_widgets()
 /**
   * Validate that correct captcha was sent
   *
-  * @return boolean TRUE if the correct captcha response was sent,
-  *                 otherwise FALSE
+  * @return mixed TRUE if the correct captcha response was sent,
+  *               FALSE if the user input was incorrect, or NULL
+  *               when no user input was given.
   *
   */
 function textcaptcha_validate_captcha()
@@ -114,7 +115,6 @@ function textcaptcha_validate_captcha()
    // just bail if insufficient input is received
    //
    if (!sqGetGlobalVar('captcha_response', $captcha_response, SQ_FORM)
-    || empty($captcha_response)
     || !sqGetGlobalVar('captcha_code', $captcha_code, SQ_SESSION)
     || empty($captcha_code))
       return FALSE;
@@ -123,6 +123,12 @@ function textcaptcha_validate_captcha()
    sqsession_unregister('captcha_code');
 
 
+   // test for no user input
+   //
+   if ($captcha_response === '')
+      return NULL;
+
+
    return strtoupper($captcha_response) == strtoupper($captcha_code);
 
 }
